#include "general.h"

int sockatmark(int fd) {
   int flag;

   if(ioctl(fd, SIOCATMARK, &flag) == -1)
      return(-1);

   return(flag ? 1 : 0);
}
